@@ -30,10 +30,10 @@ if __name__=="__main__":
         print(form)
 
     obj=Form(onsubmit=onsubmit)
-    obj<=Tag.H.input(_name="txt1",_value="1", _class="input")
-    obj<=Tag.H.input(_name="txt2",_value="2", _class="input")
-    obj<=Tag.H.input(_name="txt3",_value="3", _class="input")
-    obj<=Tag.H.input(_type="submit",_value="ok", _class="button")
+    obj<=Tag.input(_name="txt1",_value="1", _class="input")
+    obj<=Tag.input(_name="txt2",_value="2", _class="input")
+    obj<=Tag.input(_name="txt3",_value="3", _class="input")
+    obj<=Tag.input(_type="submit",_value="ok", _class="button")
 
     from . import _test
     _test( obj )
