@@ -9,10 +9,11 @@
 
 from htag import Tag
 
-class Clipboard(Tag):
+class Clipboard(Tag.div):
     tag="div"
     def __init__(self,parent):
         """ auto attach parent """
+        print("**DEPRECATED** don't use Clipboard, use the new Service !")
         super().__init__()
         parent <= self
 
@@ -30,11 +31,11 @@ tag.removeChild(ta);
 if __name__=="__main__":
     from htag.runners import PyWebWiew,BrowserHTTP
 
-    class Obj(Tag):
+    class Obj(Tag.div):
         def __init__(self):
             super().__init__()
             self.cc = Clipboard(self)
-            self<= Tag.H.button( "Copy", _onclick=self.bind.copy())
+            self<= Tag.button( "Copy", _onclick=self.bind.copy())
 
         def copy(self):
             self.cc.copy("backend text to copy in clipboard")
