@@ -17,6 +17,7 @@ class Toaster(TagBulma):
     def __init__(self, parent):
         """ auto attach on 'parent' """
         super().__init__()
+        print("**DEPRECATED** don't use Toaster, use the new Service !")
         self["info"]="toaster"
         parent.add( self )
 
@@ -25,8 +26,8 @@ class Toaster(TagBulma):
 
         jsclose= self.bind.close()
 
-        o = Tag.H.div( _class="notification has-text-light has-background-grey",_style = "position:fixed;left:0px;right:0px;bottom:0px;z-index:1000")
-        o.add( Tag.H.button(_class="delete", _onclick=jsclose) )
+        o = Tag.div( _class="notification has-text-light has-background-grey",_style = "position:fixed;left:0px;right:0px;bottom:0px;z-index:1000")
+        o.add( Tag.button(_class="delete", _onclick=jsclose) )
         o.add( content )
 
         self("""setTimeout(function() {%s;},%s);""" % (jsclose,delay))
@@ -43,7 +44,7 @@ if __name__=="__main__":
     # and not produce JS (close timeout)
     Toaster.__call__ = lambda x,y:x
 
-    obj=Tag( )
+    obj=Tag.div( )
     Toaster(obj).show( Box("Hello") )
 
     from .. import _test
